import * as WebSocket from 'ws';
import { SubscriptionManager } from 'graphql-subscriptions';
import { ExecutionResult, GraphQLSchema, DocumentNode, ValidationContext } from 'graphql';
export declare type ExecutionIterator = AsyncIterator<ExecutionResult>;
export declare type ConnectionContext = {
    initPromise?: Promise<any>;
    isLegacy: boolean;
    socket: WebSocket;
    operations: {
        [opId: string]: ExecutionIterator;
    };
};
export interface OperationMessagePayload {
    [key: string]: any;
    query?: string;
    variables?: {
        [key: string]: any;
    };
    operationName?: string;
}
export interface OperationMessage {
    payload?: OperationMessagePayload;
    id?: string;
    type: string;
}
export declare type ExecuteFunction = (schema: GraphQLSchema, document: DocumentNode, rootValue?: any, contextValue?: any, variableValues?: {
    [key: string]: any;
}, operationName?: string) => Promise<ExecutionResult> | AsyncIterator<ExecutionResult>;
export declare type SubscribeFunction = (schema: GraphQLSchema, document: DocumentNode, rootValue?: any, contextValue?: any, variableValues?: {
    [key: string]: any;
}, operationName?: string) => AsyncIterator<ExecutionResult>;
export interface ServerOptions {
    rootValue?: any;
    schema?: GraphQLSchema;
    execute?: ExecuteFunction;
    subscribe?: SubscribeFunction;
    validationRules?: Array<(context: ValidationContext) => any>;
    onOperation?: Function;
    onOperationComplete?: Function;
    onConnect?: Function;
    onDisconnect?: Function;
    keepAlive?: number;
    subscriptionManager?: SubscriptionManager;
    onSubscribe?: Function;
    onUnsubscribe?: Function;
}
export declare class SubscriptionServer {
    private onOperation;
    private onOperationComplete;
    private onConnect;
    private onDisconnect;
    private wsServer;
    private execute;
    private subscribe;
    private schema;
    private rootValue;
    private keepAlive;
    private closeHandler;
    private specifiedRules;
    private onSubscribe;
    private onUnsubscribe;
    static create(options: ServerOptions, socketOptions: WebSocket.IServerOptions): SubscriptionServer;
    constructor(options: ServerOptions, socketOptions: WebSocket.IServerOptions);
    readonly server: WebSocket.Server;
    close(): void;
    private loadExecutor(options);
    private unsubscribe(connectionContext, opId);
    private onClose(connectionContext);
    private onMessage(connectionContext);
    private sendMessage(connectionContext, opId, type, payload);
    private sendError(connectionContext, opId, errorPayload, overrideDefaultErrorType?);
}
